@@ -22,9 +22,9 @@ from editorconfig import EditorConfigError, get_properties
 # 1) function keyword, NO open/closed parentheses, e.g.   function foo
 # 2) NO function keyword, open/closed parentheses, e.g.   foo()
 FUNCTION_STYLE_REGEX = [
-    r"\bfunction\s+([\w-]+)\s*\(\s*\)\s*",
-    r"\bfunction\s+([\w-]+)\s*",
-    r"\b\s*([\w-]+)\s*\(\s*\)\s*",
+    r"\bfunction\s+([\w:@-]+)\s*\(\s*\)\s*",
+    r"\bfunction\s+([\w:@-]+)\s*",
+    r"\b\s*([\w:@-]+)\s*\(\s*\)\s*",
 ]
 
 FUNCTION_STYLE_REPLACEMENT = [r"function \g<1>() ", r"function \g<1> ", r"\g<1>() "]
@@ -482,13 +482,14 @@ class Beautify:
         parser = argparse.ArgumentParser(
             description="A Bash beautifier for the masses, version {}".format(self.get_version()),
             add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         )
         parser.add_argument(
             "--indent-size",
             "-i",
             type=int,
             default=config.get("indent_size", 4),
-            help="Sets the number of spaces to be used in " "indentation.",
+            help="Sets the number of spaces to be used in indentation.",
         )
         parser.add_argument(
             "--backup",
